==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ExplicitProxyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ExplicitProxyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Explicit Proxy Settings in Firewall Policy.
 * @property enableExplicitProxy When set to true, explicit proxy mode is enabled.
 * @property enablePacFile When set to true, pac file port and url needs to be provided.
 * @property httpPort Port number for explicit proxy http protocol, cannot be greater than 64000.
 * @property httpsPort Port number for explicit proxy https protocol, cannot be greater than 64000.
 * @property pacFile SAS URL for PAC file.
 * @property pacFilePort Port number for firewall to serve PAC file.
 */
public data class ExplicitProxyArgs(
    public val enableExplicitProxy: Output<Boolean>? = null,
    public val enablePacFile: Output<Boolean>? = null,
    public val httpPort: Output<Int>? = null,
    public val httpsPort: Output<Int>? = null,
    public val pacFile: Output<String>? = null,
    public val pacFilePort: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ExplicitProxyArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ExplicitProxyArgs =
        com.pulumi.azurenative.network.inputs.ExplicitProxyArgs.builder()
            .enableExplicitProxy(enableExplicitProxy?.applyValue({ args0 -> args0 }))
            .enablePacFile(enablePacFile?.applyValue({ args0 -> args0 }))
            .httpPort(httpPort?.applyValue({ args0 -> args0 }))
            .httpsPort(httpsPort?.applyValue({ args0 -> args0 }))
            .pacFile(pacFile?.applyValue({ args0 -> args0 }))
            .pacFilePort(pacFilePort?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExplicitProxyArgs].
 */
@PulumiTagMarker
public class ExplicitProxyArgsBuilder internal constructor() {
    private var enableExplicitProxy: Output<Boolean>? = null

    private var enablePacFile: Output<Boolean>? = null

    private var httpPort: Output<Int>? = null

    private var httpsPort: Output<Int>? = null

    private var pacFile: Output<String>? = null

    private var pacFilePort: Output<Int>? = null

    /**
     * @param value When set to true, explicit proxy mode is enabled.
     */
    @JvmName("jymxqhlcserfpngs")
    public suspend fun enableExplicitProxy(`value`: Output<Boolean>) {
        this.enableExplicitProxy = value
    }

    /**
     * @param value When set to true, pac file port and url needs to be provided.
     */
    @JvmName("xtgryewnnpupsmsx")
    public suspend fun enablePacFile(`value`: Output<Boolean>) {
        this.enablePacFile = value
    }

    /**
     * @param value Port number for explicit proxy http protocol, cannot be greater than 64000.
     */
    @JvmName("konxgpehfkhsmskm")
    public suspend fun httpPort(`value`: Output<Int>) {
        this.httpPort = value
    }

    /**
     * @param value Port number for explicit proxy https protocol, cannot be greater than 64000.
     */
    @JvmName("jwecsnnsifcuiyko")
    public suspend fun httpsPort(`value`: Output<Int>) {
        this.httpsPort = value
    }

    /**
     * @param value SAS URL for PAC file.
     */
    @JvmName("bhrgdqhylqtbyael")
    public suspend fun pacFile(`value`: Output<String>) {
        this.pacFile = value
    }

    /**
     * @param value Port number for firewall to serve PAC file.
     */
    @JvmName("hmtpyysdxbuaavny")
    public suspend fun pacFilePort(`value`: Output<Int>) {
        this.pacFilePort = value
    }

    /**
     * @param value When set to true, explicit proxy mode is enabled.
     */
    @JvmName("wscogskodrdvlvcg")
    public suspend fun enableExplicitProxy(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableExplicitProxy = mapped
    }

    /**
     * @param value When set to true, pac file port and url needs to be provided.
     */
    @JvmName("kllihnyipmkvpnel")
    public suspend fun enablePacFile(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enablePacFile = mapped
    }

    /**
     * @param value Port number for explicit proxy http protocol, cannot be greater than 64000.
     */
    @JvmName("kofqkafdwjavelex")
    public suspend fun httpPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpPort = mapped
    }

    /**
     * @param value Port number for explicit proxy https protocol, cannot be greater than 64000.
     */
    @JvmName("uwoovuhrjcnrubbt")
    public suspend fun httpsPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpsPort = mapped
    }

    /**
     * @param value SAS URL for PAC file.
     */
    @JvmName("cyskfpcpvxxfvmtq")
    public suspend fun pacFile(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pacFile = mapped
    }

    /**
     * @param value Port number for firewall to serve PAC file.
     */
    @JvmName("dufhbjqosenuysjf")
    public suspend fun pacFilePort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pacFilePort = mapped
    }

    internal fun build(): ExplicitProxyArgs = ExplicitProxyArgs(
        enableExplicitProxy = enableExplicitProxy,
        enablePacFile = enablePacFile,
        httpPort = httpPort,
        httpsPort = httpsPort,
        pacFile = pacFile,
        pacFilePort = pacFilePort,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ExplicitProxyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ExplicitProxyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Explicit Proxy Settings in Firewall Policy.
 * @property enableExplicitProxy When set to true, explicit proxy mode is enabled.
 * @property enablePacFile When set to true, pac file port and url needs to be provided.
 * @property httpPort Port number for explicit proxy http protocol, cannot be greater than 64000.
 * @property httpsPort Port number for explicit proxy https protocol, cannot be greater than 64000.
 * @property pacFile SAS URL for PAC file.
 * @property pacFilePort Port number for firewall to serve PAC file.
 */
public data class ExplicitProxyArgs(
    public val enableExplicitProxy: Output<Boolean>? = null,
    public val enablePacFile: Output<Boolean>? = null,
    public val httpPort: Output<Int>? = null,
    public val httpsPort: Output<Int>? = null,
    public val pacFile: Output<String>? = null,
    public val pacFilePort: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ExplicitProxyArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ExplicitProxyArgs =
        com.pulumi.azurenative.network.inputs.ExplicitProxyArgs.builder()
            .enableExplicitProxy(enableExplicitProxy?.applyValue({ args0 -> args0 }))
            .enablePacFile(enablePacFile?.applyValue({ args0 -> args0 }))
            .httpPort(httpPort?.applyValue({ args0 -> args0 }))
            .httpsPort(httpsPort?.applyValue({ args0 -> args0 }))
            .pacFile(pacFile?.applyValue({ args0 -> args0 }))
            .pacFilePort(pacFilePort?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExplicitProxyArgs].
 */
@PulumiTagMarker
public class ExplicitProxyArgsBuilder internal constructor() {
    private var enableExplicitProxy: Output<Boolean>? = null

    private var enablePacFile: Output<Boolean>? = null

    private var httpPort: Output<Int>? = null

    private var httpsPort: Output<Int>? = null

    private var pacFile: Output<String>? = null

    private var pacFilePort: Output<Int>? = null

    /**
     * @param value When set to true, explicit proxy mode is enabled.
     */
    @JvmName("bprcavrqdmvhhkng")
    public suspend fun enableExplicitProxy(`value`: Output<Boolean>) {
        this.enableExplicitProxy = value
    }

    /**
     * @param value When set to true, pac file port and url needs to be provided.
     */
    @JvmName("mptnrlhputxaidho")
    public suspend fun enablePacFile(`value`: Output<Boolean>) {
        this.enablePacFile = value
    }

    /**
     * @param value Port number for explicit proxy http protocol, cannot be greater than 64000.
     */
    @JvmName("tfhlfqbkggvxsasp")
    public suspend fun httpPort(`value`: Output<Int>) {
        this.httpPort = value
    }

    /**
     * @param value Port number for explicit proxy https protocol, cannot be greater than 64000.
     */
    @JvmName("pgmmeoimvaihuhgy")
    public suspend fun httpsPort(`value`: Output<Int>) {
        this.httpsPort = value
    }

    /**
     * @param value SAS URL for PAC file.
     */
    @JvmName("erjhfegcwhqehjyk")
    public suspend fun pacFile(`value`: Output<String>) {
        this.pacFile = value
    }

    /**
     * @param value Port number for firewall to serve PAC file.
     */
    @JvmName("mvdkixhwnijxxroi")
    public suspend fun pacFilePort(`value`: Output<Int>) {
        this.pacFilePort = value
    }

    /**
     * @param value When set to true, explicit proxy mode is enabled.
     */
    @JvmName("rukbvneykgmmxvvi")
    public suspend fun enableExplicitProxy(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableExplicitProxy = mapped
    }

    /**
     * @param value When set to true, pac file port and url needs to be provided.
     */
    @JvmName("ayplnthemiadggmh")
    public suspend fun enablePacFile(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enablePacFile = mapped
    }

    /**
     * @param value Port number for explicit proxy http protocol, cannot be greater than 64000.
     */
    @JvmName("ekrtxsvorkhhybiv")
    public suspend fun httpPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpPort = mapped
    }

    /**
     * @param value Port number for explicit proxy https protocol, cannot be greater than 64000.
     */
    @JvmName("wdvwslwxbbilstra")
    public suspend fun httpsPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpsPort = mapped
    }

    /**
     * @param value SAS URL for PAC file.
     */
    @JvmName("adbhymnrlhooqlnc")
    public suspend fun pacFile(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pacFile = mapped
    }

    /**
     * @param value Port number for firewall to serve PAC file.
     */
    @JvmName("pnlindwojpstbsho")
    public suspend fun pacFilePort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pacFilePort = mapped
    }

    internal fun build(): ExplicitProxyArgs = ExplicitProxyArgs(
        enableExplicitProxy = enableExplicitProxy,
        enablePacFile = enablePacFile,
        httpPort = httpPort,
        httpsPort = httpsPort,
        pacFile = pacFile,
        pacFilePort = pacFilePort,
    )
}
